==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QAbstractClipBlendNode.java <==
package io.qt.qt3d.animation;


/**
 * <p>The base class for types used to construct animation blend trees</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qabstractclipblendnode.html">Qt3DAnimation::QAbstractClipBlendNode</a></p>
 */
public class QAbstractClipBlendNode extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractClipBlendNode.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAbstractClipBlendNode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    protected QAbstractClipBlendNode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    protected QAbstractClipBlendNode(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAbstractClipBlendNode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractClipBlendNode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAbstractClipBlendNode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAbstractClipBlendNode instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2.1-sources.jar: io/qt/qt3d/animation/QAbstractClipBlendNode.java <==
package io.qt.qt3d.animation;


/**
 * <p>The base class for types used to construct animation blend trees</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qabstractclipblendnode.html">Qt3DAnimation::QAbstractClipBlendNode</a></p>
 */
public class QAbstractClipBlendNode extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractClipBlendNode.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAbstractClipBlendNode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    protected QAbstractClipBlendNode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    protected QAbstractClipBlendNode(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAbstractClipBlendNode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractClipBlendNode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAbstractClipBlendNode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAbstractClipBlendNode instance, QDeclarativeConstructor constructor);
    
}
